@@ -3,9 +3,13 @@ package tim.prune;
 import tim.prune.correlate.AudioCorrelator;
 import tim.prune.correlate.PhotoCorrelator;
 import tim.prune.function.*;
+import tim.prune.function.autoplay.AutoplayFunction;
 import tim.prune.function.charts.Charter;
 import tim.prune.function.compress.CompressTrackFunction;
+import tim.prune.function.compress.DeleteMarkedPointsFunction;
+import tim.prune.function.compress.MarkLiftsFunction;
 import tim.prune.function.compress.MarkPointsInRectangleFunction;
+import tim.prune.function.deletebydate.DeleteByDateFunction;
 import tim.prune.function.distance.DistanceFunction;
 import tim.prune.function.edit.PointNameEditor;
 import tim.prune.function.estimate.EstimateTime;
@@ -42,18 +46,22 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_IMPORTBABEL = null;
 	public static GenericFunction FUNCTION_SAVECONFIG  = null;
 	public static GenericFunction FUNCTION_EDIT_WAYPOINT_NAME = null;
-	public static RearrangeWaypointsFunction FUNCTION_REARRANGE_WAYPOINTS = null;
+	public static GenericFunction FUNCTION_REARRANGE_WAYPOINTS = null;
+	public static GenericFunction FUNCTION_SELECT_SEGMENT = null;
 	public static GenericFunction FUNCTION_SPLIT_SEGMENTS = null;
 	public static GenericFunction FUNCTION_SEW_SEGMENTS = null;
 	public static GenericFunction FUNCTION_REARRANGE_PHOTOS = null;
 	public static GenericFunction FUNCTION_COMPRESS = null;
+	public static GenericFunction FUNCTION_MARK_LIFTS = null;
+	public static DeleteMarkedPointsFunction FUNCTION_DELETE_MARKED_POINTS = null;
 	public static GenericFunction FUNCTION_DELETE_RANGE = null;
 	public static GenericFunction FUNCTION_CROP_TRACK = null;
 	public static GenericFunction FUNCTION_MARK_IN_RECTANGLE = null;
-	public static GenericFunction FUNCTION_INTERPOLATE = null;
+	public static GenericFunction FUNCTION_DELETE_BY_DATE = null;
+	public static SingleNumericParameterFunction FUNCTION_INTERPOLATE = null;
 	public static GenericFunction FUNCTION_LOOKUP_SRTM = null;
 	public static GenericFunction FUNCTION_DOWNLOAD_SRTM = null;
-	public static GenericFunction FUNCTION_LOOKUP_WIKIPEDIA = null;
+	public static GenericFunction FUNCTION_NEARBY_WIKIPEDIA = null;
 	public static GenericFunction FUNCTION_SEARCH_WIKIPEDIA = null;
 	public static GenericFunction FUNCTION_DOWNLOAD_OSM = null;
 	public static GenericFunction FUNCTION_ADD_TIME_OFFSET  = null;
@@ -76,6 +84,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_3D     = null;
 	public static GenericFunction FUNCTION_DISTANCES  = null;
 	public static GenericFunction FUNCTION_FULL_RANGE_DETAILS = null;
+	public static GenericFunction FUNCTION_AUTOPLAY_TRACK = null;
 	public static GenericFunction FUNCTION_ESTIMATE_TIME = null;
 	public static GenericFunction FUNCTION_LEARN_ESTIMATION_PARAMS = null;
 	public static GenericFunction FUNCTION_GET_GPSIES = null;
@@ -90,8 +99,9 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_SET_DISK_CACHE = null;
 	public static GenericFunction FUNCTION_SET_PATHS  = null;
 	public static GenericFunction FUNCTION_SET_COLOURS = null;
-	public static GenericFunction FUNCTION_SET_LINE_WIDTH = null;
+	public static SingleNumericParameterFunction FUNCTION_SET_LINE_WIDTH = null;
 	public static GenericFunction FUNCTION_SET_LANGUAGE = null;
+	public static SingleNumericParameterFunction FUNCTION_SET_ALTITUDE_TOLERANCE = null;
 	public static GenericFunction FUNCTION_HELP   = null;
 	public static GenericFunction FUNCTION_SHOW_KEYS = null;
 	public static GenericFunction FUNCTION_ABOUT  = null;
@@ -115,17 +125,21 @@ public abstract class FunctionLibrary
 		FUNCTION_SAVECONFIG = new SaveConfig(inApp);
 		FUNCTION_EDIT_WAYPOINT_NAME = new PointNameEditor(inApp);
 		FUNCTION_REARRANGE_WAYPOINTS = new RearrangeWaypointsFunction(inApp);
+		FUNCTION_SELECT_SEGMENT = new SelectSegmentFunction(inApp);
 		FUNCTION_SPLIT_SEGMENTS = new SplitSegmentsFunction(inApp);
 		FUNCTION_SEW_SEGMENTS = new SewTrackSegmentsFunction(inApp);
 		FUNCTION_REARRANGE_PHOTOS = new RearrangePhotosFunction(inApp);
 		FUNCTION_COMPRESS = new CompressTrackFunction(inApp);
+		FUNCTION_MARK_LIFTS = new MarkLiftsFunction(inApp);
+		FUNCTION_DELETE_MARKED_POINTS = new DeleteMarkedPointsFunction(inApp);
 		FUNCTION_DELETE_RANGE = new DeleteSelectedRangeFunction(inApp);
 		FUNCTION_CROP_TRACK = new CropToSelection(inApp);
 		FUNCTION_MARK_IN_RECTANGLE = new MarkPointsInRectangleFunction(inApp);
+		FUNCTION_DELETE_BY_DATE = new DeleteByDateFunction(inApp);
 		FUNCTION_INTERPOLATE = new InterpolateFunction(inApp);
 		FUNCTION_LOOKUP_SRTM = new LookupSrtmFunction(inApp);
 		FUNCTION_DOWNLOAD_SRTM = new DownloadSrtmFunction(inApp);
-		FUNCTION_LOOKUP_WIKIPEDIA = new GetWikipediaFunction(inApp);
+		FUNCTION_NEARBY_WIKIPEDIA = new GetWikipediaFunction(inApp);
 		FUNCTION_SEARCH_WIKIPEDIA = new SearchWikipediaNames(inApp);
 		FUNCTION_DOWNLOAD_OSM = new DownloadOsmFunction(inApp);
 		FUNCTION_ADD_TIME_OFFSET = new AddTimeOffset(inApp);
@@ -147,6 +161,7 @@ public abstract class FunctionLibrary
 		FUNCTION_3D     = new ShowThreeDFunction(inApp);
 		FUNCTION_DISTANCES = new DistanceFunction(inApp);
 		FUNCTION_FULL_RANGE_DETAILS = new FullRangeDetails(inApp);
+		FUNCTION_AUTOPLAY_TRACK = new AutoplayFunction(inApp);
 		FUNCTION_ESTIMATE_TIME = new EstimateTime(inApp);
 		FUNCTION_LEARN_ESTIMATION_PARAMS = new LearnParameters(inApp);
 		FUNCTION_GET_GPSIES = new GetGpsiesFunction(inApp);
@@ -164,6 +179,7 @@ public abstract class FunctionLibrary
 		FUNCTION_SET_COLOURS = new SetColours(inApp);
 		FUNCTION_SET_LINE_WIDTH = new SetLineWidth(inApp);
 		FUNCTION_SET_LANGUAGE = new SetLanguage(inApp);
+		FUNCTION_SET_ALTITUDE_TOLERANCE = new SetAltitudeTolerance(inApp);
 		FUNCTION_HELP   = new HelpScreen(inApp);
 		FUNCTION_SHOW_KEYS = new ShowKeysScreen(inApp);
 		FUNCTION_ABOUT  = new AboutScreen(inApp);
