@@ -9,7 +9,7 @@ import java.io.File;
 public class SourceInfo
 {
 	/** File type of source file */
-	public enum FILE_TYPE {TEXT, GPX, KML, NMEA, GPSBABEL, GPSIES};
+	public enum FILE_TYPE {TEXT, GPX, KML, NMEA, GPSBABEL, GPSIES, JSON};
 
 	/** Source file */
 	private File _sourceFile = null;
@@ -122,8 +122,12 @@ public class SourceInfo
 	public int getIndex(DataPoint inPoint)
 	{
 		int idx = -1;
-		for (int i=0; i<_points.length && (idx < 0); i++) {
-			if (_points[i] == inPoint) {idx = i;}
+		for (int i=0; i<_points.length; i++)
+		{
+			if (_points[i] == inPoint) {
+				idx = i;
+				break;
+			}
 		}
 		if (idx == -1) {return idx;}             // point not found
 		if (_pointIndices == null) {return idx;} // All points loaded
