@@ -21,6 +21,7 @@ import tim.prune.I18nManager;
 import tim.prune.UpdateMessageBroker;
 import tim.prune.config.Config;
 import tim.prune.data.AudioClip;
+import tim.prune.data.DataPoint;
 import tim.prune.data.Field;
 import tim.prune.data.Photo;
 import tim.prune.data.RecentFile;
@@ -28,8 +29,11 @@ import tim.prune.data.RecentFileList;
 import tim.prune.data.Selection;
 import tim.prune.data.Track;
 import tim.prune.data.TrackInfo;
-import tim.prune.function.RearrangeWaypointsFunction.Rearrange;
+import tim.prune.function.ChooseSingleParameter;
+import tim.prune.function.SearchOpenCachingDeFunction;
 import tim.prune.function.browser.UrlGenerator;
+import tim.prune.function.browser.WebMapFunction;
+import tim.prune.function.search.SearchMapillaryFunction;
 
 /**
  * Class to manage the menu bar and tool bar,
@@ -59,11 +63,14 @@ public class MenuManager implements DataSubscriber
 	private JMenuItem _cropTrackItem = null;
 	private JMenuItem _compressItem = null;
 	private JMenuItem _markRectangleItem = null;
+	private JMenuItem _markUphillLiftsItem = null;
 	private JMenuItem _deleteMarkedPointsItem = null;
+	private JMenuItem _deleteByDateItem = null;
 	private JMenuItem _interpolateItem = null;
 	private JMenuItem _averageItem = null;
 	private JMenuItem _selectAllItem = null;
 	private JMenuItem _selectNoneItem = null;
+	private JMenuItem _selectSegmentItem = null;
 	private JMenuItem _selectStartItem = null;
 	private JMenuItem _selectEndItem = null;
 	private JMenuItem _findWaypointItem = null;
@@ -72,7 +79,7 @@ public class MenuManager implements DataSubscriber
 	private JMenuItem _addTimeOffsetItem = null;
 	private JMenuItem _addAltitudeOffsetItem = null;
 	private JMenuItem _mergeSegmentsItem = null;
-	private JMenu     _rearrangeMenu = null;
+	private JMenuItem _rearrangeWaypointsItem = null;
 	private JMenuItem _splitSegmentsItem = null;
 	private JMenuItem _sewSegmentsItem = null;
 	private JMenuItem _cutAndMoveItem = null;
@@ -86,13 +93,20 @@ public class MenuManager implements DataSubscriber
 	private JMenuItem _uploadGpsiesItem = null;
 	private JMenuItem _lookupSrtmItem = null;
 	private JMenuItem _downloadSrtmItem = null;
-	private JMenuItem _lookupWikipediaItem = null;
+	private JMenuItem _nearbyWikipediaItem = null;
+	private JMenuItem _showPeakfinderItem = null;
+	private JMenuItem _showGeohackItem = null;
+	private JMenuItem _showPanoramioItem = null;
+	private JMenuItem _showOpencachingComItem = null;
+	private JMenuItem _searchOpencachingDeItem = null;
+	private JMenuItem _searchMapillaryItem = null;
 	private JMenuItem _downloadOsmItem = null;
 	private JMenuItem _getWeatherItem = null;
 	private JMenuItem _distanceItem = null;
 	private JMenuItem _fullRangeDetailsItem = null;
 	private JMenuItem _estimateTimeItem = null;
 	private JMenuItem _learnEstimationParams = null;
+	private JMenuItem _autoplayTrack = null;
 	private JMenuItem _saveExifItem = null;
 	private JMenuItem _photoPopupItem = null;
 	private JMenuItem _selectNoPhotoItem = null;
@@ -110,6 +124,7 @@ public class MenuManager implements DataSubscriber
 	private JMenuItem _correlateAudiosItem = null;
 	private JMenuItem _selectNoAudioItem = null;
 	private JCheckBoxMenuItem _onlineCheckbox = null;
+	private JCheckBoxMenuItem _antialiasCheckbox = null;
 	private JCheckBoxMenuItem _autosaveSettingsCheckbox = null;
 
 	// ActionListeners for reuse by menu and toolbar
@@ -254,14 +269,43 @@ public class MenuManager implements DataSubscriber
 		// Upload to gpsies
 		_uploadGpsiesItem = makeMenuItem(FunctionLibrary.FUNCTION_UPLOAD_GPSIES, false);
 		onlineMenu.add(_uploadGpsiesItem);
+
 		onlineMenu.addSeparator();
-		_lookupWikipediaItem = makeMenuItem(FunctionLibrary.FUNCTION_LOOKUP_WIKIPEDIA, false);
-		onlineMenu.add(_lookupWikipediaItem);
+		// browser submenu
+		_browserMapMenu = new JMenu(I18nManager.getText("menu.view.browser"));
+		_browserMapMenu.setEnabled(false);
+		JMenuItem googleMapsItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_GOOGLE, "menu.view.browser.google"));
+		_browserMapMenu.add(googleMapsItem);
+		JMenuItem openMapsItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_OSM, "menu.view.browser.openstreetmap"));
+		_browserMapMenu.add(openMapsItem);
+		JMenuItem mapquestMapsItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_MAPQUEST, "menu.view.browser.mapquest"));
+		_browserMapMenu.add(mapquestMapsItem);
+		JMenuItem yahooMapsItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_YAHOO, "menu.view.browser.yahoo"));
+		_browserMapMenu.add(yahooMapsItem);
+		JMenuItem bingMapsItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_BING, "menu.view.browser.bing"));
+		_browserMapMenu.add(bingMapsItem);
+		onlineMenu.add(_browserMapMenu);
+		// wikipedia
+		_nearbyWikipediaItem = makeMenuItem(FunctionLibrary.FUNCTION_NEARBY_WIKIPEDIA, false);
+		onlineMenu.add(_nearbyWikipediaItem);
 		JMenuItem searchWikipediaNamesItem = makeMenuItem(FunctionLibrary.FUNCTION_SEARCH_WIKIPEDIA);
 		onlineMenu.add(searchWikipediaNamesItem);
+		_showPeakfinderItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_PEAKFINDER, "webservice.peakfinder"), false);
+		onlineMenu.add(_showPeakfinderItem);
+		_showGeohackItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_GEOHACK, "webservice.geohack"), false);
+		onlineMenu.add(_showGeohackItem);
+		_showPanoramioItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_PANORAMIO, "webservice.panoramio"), false);
+		onlineMenu.add(_showPanoramioItem);
+		_showOpencachingComItem = makeMenuItem(new WebMapFunction(_app, UrlGenerator.WebService.MAP_SOURCE_OPENCACHINGCOM, "webservice.opencachingcom"), false);
+		onlineMenu.add(_showOpencachingComItem);
+
+		onlineMenu.addSeparator();
+		_searchOpencachingDeItem = makeMenuItem(new SearchOpenCachingDeFunction(_app), false);
+		onlineMenu.add(_searchOpencachingDeItem);
+		_searchMapillaryItem = makeMenuItem(new SearchMapillaryFunction(_app), false);
+		onlineMenu.add(_searchMapillaryItem);
 		_downloadOsmItem = makeMenuItem(FunctionLibrary.FUNCTION_DOWNLOAD_OSM, false);
 		onlineMenu.add(_downloadOsmItem);
-		onlineMenu.addSeparator();
 		_getWeatherItem = makeMenuItem(FunctionLibrary.FUNCTION_GET_WEATHER_FORECAST, false);
 		onlineMenu.add(_getWeatherItem);
 		menubar.add(onlineMenu);
@@ -301,43 +345,16 @@ public class MenuManager implements DataSubscriber
 		});
 		_markRectangleItem.setEnabled(false);
 		trackMenu.add(_markRectangleItem);
-		_deleteMarkedPointsItem = new JMenuItem(I18nManager.getText("menu.track.deletemarked"));
-		_deleteMarkedPointsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.finishCompressTrack();
-			}
-		});
-		_deleteMarkedPointsItem.setEnabled(false);
+		_markUphillLiftsItem = makeMenuItem(FunctionLibrary.FUNCTION_MARK_LIFTS, false);
+		trackMenu.add(_markUphillLiftsItem);
+		_deleteMarkedPointsItem = makeMenuItem(FunctionLibrary.FUNCTION_DELETE_MARKED_POINTS, false);
 		trackMenu.add(_deleteMarkedPointsItem);
+		_deleteByDateItem = makeMenuItem(FunctionLibrary.FUNCTION_DELETE_BY_DATE, false);
+		trackMenu.add(_deleteByDateItem);
 		trackMenu.addSeparator();
 		// Rearrange waypoints
-		_rearrangeMenu = new JMenu(I18nManager.getText("menu.track.rearrange"));
-		_rearrangeMenu.setEnabled(false);
-		JMenuItem  rearrangeStartItem = new JMenuItem(I18nManager.getText("menu.track.rearrange.start"));
-		rearrangeStartItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				FunctionLibrary.FUNCTION_REARRANGE_WAYPOINTS.rearrangeWaypoints(Rearrange.TO_START);
-			}
-		});
-		rearrangeStartItem.setEnabled(true);
-		_rearrangeMenu.add(rearrangeStartItem);
-		JMenuItem rearrangeEndItem = new JMenuItem(I18nManager.getText("menu.track.rearrange.end"));
-		rearrangeEndItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				FunctionLibrary.FUNCTION_REARRANGE_WAYPOINTS.rearrangeWaypoints(Rearrange.TO_END);
-			}
-		});
-		rearrangeEndItem.setEnabled(true);
-		_rearrangeMenu.add(rearrangeEndItem);
-		JMenuItem rearrangeNearestItem = new JMenuItem(I18nManager.getText("menu.track.rearrange.nearest"));
-		rearrangeNearestItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				FunctionLibrary.FUNCTION_REARRANGE_WAYPOINTS.rearrangeWaypoints(Rearrange.TO_NEAREST);
-			}
-		});
-		rearrangeNearestItem.setEnabled(true);
-		_rearrangeMenu.add(rearrangeNearestItem);
-		trackMenu.add(_rearrangeMenu);
+		_rearrangeWaypointsItem = makeMenuItem(FunctionLibrary.FUNCTION_REARRANGE_WAYPOINTS, false);
+		trackMenu.add(_rearrangeWaypointsItem);
 		// Split track segments
 		_splitSegmentsItem = makeMenuItem(FunctionLibrary.FUNCTION_SPLIT_SEGMENTS, false);
 		trackMenu.add(_splitSegmentsItem);
@@ -369,6 +386,8 @@ public class MenuManager implements DataSubscriber
 			}
 		});
 		rangeMenu.add(_selectNoneItem);
+		_selectSegmentItem = makeMenuItem(FunctionLibrary.FUNCTION_SELECT_SEGMENT);
+		rangeMenu.add(_selectSegmentItem);
 		rangeMenu.addSeparator();
 		_selectStartItem = new JMenuItem(I18nManager.getText("menu.range.start"));
 		_selectStartItem.setEnabled(false);
@@ -416,7 +435,7 @@ public class MenuManager implements DataSubscriber
 		_deleteFieldValuesItem = makeMenuItem(FunctionLibrary.FUNCTION_DELETE_FIELD_VALUES, false);
 		rangeMenu.add(_deleteFieldValuesItem);
 		rangeMenu.addSeparator();
-		_interpolateItem = makeMenuItem(FunctionLibrary.FUNCTION_INTERPOLATE, false);
+		_interpolateItem = makeMenuItem(new ChooseSingleParameter(_app, FunctionLibrary.FUNCTION_INTERPOLATE), false);
 		rangeMenu.add(_interpolateItem);
 		_averageItem = new JMenuItem(I18nManager.getText("menu.range.average"));
 		_averageItem.addActionListener(new ActionListener() {
@@ -501,45 +520,6 @@ public class MenuManager implements DataSubscriber
 		// 3d
 		_show3dItem = makeMenuItem(FunctionLibrary.FUNCTION_3D, false);
 		viewMenu.add(_show3dItem);
-		// browser submenu
-		_browserMapMenu = new JMenu(I18nManager.getText("menu.view.browser"));
-		_browserMapMenu.setEnabled(false);
-		JMenuItem googleMapsItem = new JMenuItem(I18nManager.getText("menu.view.browser.google"));
-		googleMapsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.showExternalMap(UrlGenerator.MAP_SOURCE_GOOGLE);
-			}
-		});
-		_browserMapMenu.add(googleMapsItem);
-		JMenuItem openMapsItem = new JMenuItem(I18nManager.getText("menu.view.browser.openstreetmap"));
-		openMapsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.showExternalMap(UrlGenerator.MAP_SOURCE_OSM);
-			}
-		});
-		_browserMapMenu.add(openMapsItem);
-		JMenuItem mapquestMapsItem = new JMenuItem(I18nManager.getText("menu.view.browser.mapquest"));
-		mapquestMapsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.showExternalMap(UrlGenerator.MAP_SOURCE_MAPQUEST);
-			}
-		});
-		_browserMapMenu.add(mapquestMapsItem);
-		JMenuItem yahooMapsItem = new JMenuItem(I18nManager.getText("menu.view.browser.yahoo"));
-		yahooMapsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.showExternalMap(UrlGenerator.MAP_SOURCE_YAHOO);
-			}
-		});
-		_browserMapMenu.add(yahooMapsItem);
-		JMenuItem bingMapsItem = new JMenuItem(I18nManager.getText("menu.view.browser.bing"));
-		bingMapsItem.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				_app.showExternalMap(UrlGenerator.MAP_SOURCE_BING);
-			}
-		});
-		_browserMapMenu.add(bingMapsItem);
-		viewMenu.add(_browserMapMenu);
 		// Charts
 		_chartItem = makeMenuItem(FunctionLibrary.FUNCTION_CHARTS, false);
 		viewMenu.add(_chartItem);
@@ -553,6 +533,10 @@ public class MenuManager implements DataSubscriber
 		// estimate time
 		_estimateTimeItem = makeMenuItem(FunctionLibrary.FUNCTION_ESTIMATE_TIME, false);
 		viewMenu.add(_estimateTimeItem);
+		viewMenu.addSeparator();
+		// autoplay
+		_autoplayTrack = makeMenuItem(FunctionLibrary.FUNCTION_AUTOPLAY_TRACK, false);
+		viewMenu.add(_autoplayTrack);
 		menubar.add(viewMenu);
 
 		// Add photo menu
@@ -657,9 +641,21 @@ public class MenuManager implements DataSubscriber
 		// Set colours
 		settingsMenu.add(makeMenuItem(FunctionLibrary.FUNCTION_SET_COLOURS));
 		// Set line width used for drawing
-		settingsMenu.add(makeMenuItem(FunctionLibrary.FUNCTION_SET_LINE_WIDTH));
+		settingsMenu.add(makeMenuItem(new ChooseSingleParameter(_app, FunctionLibrary.FUNCTION_SET_LINE_WIDTH)));
+		// Use antialias or not
+		_antialiasCheckbox = new JCheckBoxMenuItem(I18nManager.getText("menu.settings.antialias"), false);
+		_antialiasCheckbox.setSelected(Config.getConfigBoolean(Config.KEY_ANTIALIAS));
+		_antialiasCheckbox.addActionListener(new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				Config.setConfigBoolean(Config.KEY_ANTIALIAS, _antialiasCheckbox.isSelected());
+				UpdateMessageBroker.informSubscribers(MAPSERVER_CHANGED);
+			}
+		});
+			settingsMenu.add(_antialiasCheckbox);
 		// Set language
 		settingsMenu.add(makeMenuItem(FunctionLibrary.FUNCTION_SET_LANGUAGE));
+		// Set altitude tolerance
+		settingsMenu.add(makeMenuItem(new ChooseSingleParameter(_app, FunctionLibrary.FUNCTION_SET_ALTITUDE_TOLERANCE)));
 		settingsMenu.addSeparator();
 		// Save configuration
 		settingsMenu.add(makeMenuItem(FunctionLibrary.FUNCTION_SAVECONFIG));
@@ -876,8 +872,9 @@ public class MenuManager implements DataSubscriber
 		_exportImageItem.setEnabled(hasMultiplePoints);
 		_compressItem.setEnabled(hasData);
 		_markRectangleItem.setEnabled(hasData);
+		_markUphillLiftsItem.setEnabled(hasData && _track.hasAltitudeData());
 		_deleteMarkedPointsItem.setEnabled(hasData && _track.hasMarkedPoints());
-		_rearrangeMenu.setEnabled(hasData && _track.hasTrackPoints() && _track.hasWaypoints());
+		_rearrangeWaypointsItem.setEnabled(hasData && _track.hasTrackPoints() && _track.hasWaypoints());
 		_splitSegmentsItem.setEnabled(hasData && _track.hasTrackPoints() && _track.getNumPoints() > 3);
 		_sewSegmentsItem.setEnabled(hasData && _track.hasTrackPoints() && _track.getNumPoints() > 3);
 		_selectAllItem.setEnabled(hasData);
@@ -886,15 +883,18 @@ public class MenuManager implements DataSubscriber
 		_chartItem.setEnabled(hasData);
 		_browserMapMenu.setEnabled(hasData);
 		_distanceItem.setEnabled(hasData);
+		_autoplayTrack.setEnabled(hasData && _track.getNumPoints() > 3);
 		_getGpsiesItem.setEnabled(hasData);
 		_uploadGpsiesItem.setEnabled(hasData && _track.hasTrackPoints());
 		_lookupSrtmItem.setEnabled(hasData);
-		_lookupWikipediaItem.setEnabled(hasData);
+		_nearbyWikipediaItem.setEnabled(hasData);
 		_downloadOsmItem.setEnabled(hasData);
 		_getWeatherItem.setEnabled(hasData);
 		_findWaypointItem.setEnabled(hasData && _track.hasWaypoints());
 		// have we got a cache?
 		_downloadSrtmItem.setEnabled(hasData && Config.getConfigString(Config.KEY_DISK_CACHE) != null);
+		// have we got any timestamps?
+		_deleteByDateItem.setEnabled(hasData && _track.hasData(Field.TIMESTAMP));
 
 		// is undo available?
 		boolean hasUndo = !_app.getUndoStack().isEmpty();
@@ -902,7 +902,8 @@ public class MenuManager implements DataSubscriber
 		_undoButton.setEnabled(hasUndo);
 		_clearUndoItem.setEnabled(hasUndo);
 		// is there a current point?
-		boolean hasPoint = (hasData && _selection.getCurrentPointIndex() >= 0);
+		DataPoint currPoint = _app.getTrackInfo().getCurrentPoint();
+		boolean hasPoint = (currPoint != null);
 		_editPointItem.setEnabled(hasPoint);
 		_editPointButton.setEnabled(hasPoint);
 		_editWaypointNameItem.setEnabled(hasPoint);
@@ -913,6 +914,14 @@ public class MenuManager implements DataSubscriber
 		_selectEndItem.setEnabled(hasPoint);
 		_selectEndButton.setEnabled(hasPoint);
 		_duplicatePointItem.setEnabled(hasPoint);
+		_showPeakfinderItem.setEnabled(hasPoint);
+		_showGeohackItem.setEnabled(hasPoint);
+		_showPanoramioItem.setEnabled(hasPoint);
+		_showOpencachingComItem.setEnabled(hasPoint);
+		_searchOpencachingDeItem.setEnabled(hasPoint);
+		_searchMapillaryItem.setEnabled(hasPoint);
+		// is it a waypoint?
+		_selectSegmentItem.setEnabled(hasPoint && !currPoint.isWaypoint());
 		// are there any photos?
 		boolean anyPhotos = _app.getTrackInfo().getPhotoList().getNumPhotos() > 0;
 		_saveExifItem.setEnabled(anyPhotos && _app.getTrackInfo().getPhotoList().hasMediaWithFile());
@@ -939,7 +948,7 @@ public class MenuManager implements DataSubscriber
 		_selectNoAudioItem.setEnabled(hasAudio);
 		_removeAudioItem.setEnabled(hasAudio);
 		_connectAudioItem.setEnabled(hasAudio && hasPoint && currentAudio.getDataPoint() == null);
-		_disconnectAudioItem.setEnabled(hasAudio && _app.getTrackInfo().getCurrentAudio().getDataPoint() != null);
+		_disconnectAudioItem.setEnabled(hasAudio && currentAudio.getDataPoint() != null);
 		_correlateAudiosItem.setEnabled(anyAudios && hasData);
 		// is there a current range?
 		boolean hasRange = (hasData && _selection.hasRangeSelected());
@@ -983,8 +992,9 @@ public class MenuManager implements DataSubscriber
 				for (int i=0; i<numRecentFiles; i++)
 				{
 					JMenuItem item = _recentFileMenu.getItem(i);
-					item.setText(rfl.getFile(i)==null?"":rfl.getFile(i).getFile().getName());
-					item.setToolTipText(rfl.getFile(i)==null?null:rfl.getFile(i).getFile().getAbsolutePath());
+					RecentFile rf = rfl.getFile(i);
+					item.setText(rf==null?"":rf.getFile().getName());
+					item.setToolTipText(rf==null?null:rf.getFile().getAbsolutePath());
 				}
 			}
 			else
