@@ -84,11 +84,19 @@ public abstract class MapSource
 	{
 		if (inUrl == null || inUrl.equals("")) {return null;}
 		String urlstr = inUrl;
+		boolean urlOk = false;
+
 		// check prefix
-		try {
-			new URL(urlstr.replace('[', 'w').replace(']', 'w'));
+		try
+		{
+			urlOk = new URL(urlstr.replace('[', 'w').replace(']', 'w')) != null;
 		}
 		catch (MalformedURLException e)
+		{
+			urlOk = false;
+		}
+
+		if (!urlOk)
 		{
 			// fail if protocol specified
 			if (urlstr.indexOf("://") >= 0) {return null;}
@@ -100,7 +108,8 @@ public abstract class MapSource
 			urlstr = urlstr + "/";
 		}
 		// Validate current url, return null if not ok
-		try {
+		try
+		{
 			URL url = new URL(urlstr.replace('[', 'w').replace(']', 'w'));
 			// url host must contain a dot
 			if (url.getHost().indexOf('.') < 0) {return null;}
