@@ -4,10 +4,13 @@ import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.RenderingHints;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
+
 import javax.swing.JLabel;
 import javax.swing.JMenuItem;
 import javax.swing.JPopupMenu;
@@ -86,6 +89,9 @@ public class ProfileChart extends GenericDisplay implements MouseListener
 	public void paint(Graphics g)
 	{
 		super.paint(g);
+		// Set antialiasing depending on Config
+		((Graphics2D) g).setRenderingHint(RenderingHints.KEY_ANTIALIASING,
+			Config.getConfigBoolean(Config.KEY_ANTIALIAS) ? RenderingHints.VALUE_ANTIALIAS_ON : RenderingHints.VALUE_ANTIALIAS_OFF);
 		ColourScheme colourScheme = Config.getColourScheme();
 		paintBackground(g, colourScheme);
 		if (_track != null && _track.getNumPoints() > 0)
