@@ -11,7 +11,7 @@ public abstract class BabelFileFormats
 	/**
 	 * @return an object array for the format descriptions
 	 */
-	public static Object[] getDescriptions() {
+	public static String[] getDescriptions() {
 		return getColumn(0);
 	}
 
@@ -26,8 +26,10 @@ public abstract class BabelFileFormats
 		{
 			final String[] suffixes = getColumn(2);
 			for (int i=0; i<suffixes.length; i++)
+			{
 				if (suffixes[i] != null && suffixes[i].equalsIgnoreCase(inSuffix))
 					return i;
+			}
 		}
 		return -1;
 	}
